#========================================================================================
# package      DE_EPAGES::GoogleSmartShopping::API::Constants
# state        public
#----------------------------------------------------------------------------------------
# description  This is the place for common GoogleSmartShopping values and constants.
#========================================================================================
package DE_EPAGES::GoogleSmartShopping::API::Constants;
use base Exporter;

use strict;

our @EXPORT_OK = qw (
    ACCOUNT_ISSUE_TRANSLATION_KEYS
    GOOGLE_SMART_SHOPPING_APP_SCOPES
    GOOGLE_ERROR_CODES
    EPAGESJ_BASE_URI
    MERCHANT_CENTER_REQUIREMENTS_CHECK_LIST
    ERROR_UNKNOWN
    ERROR_FORM_SUBMIT
    ERROR_ACCEPT_TERMS
    ERROR_TOKEN_EXPIRED_OR_REVOKED
    ERROR_GET_VERIFICATION_TOKEN_FAILED
    ERROR_UNAUTHENTICATED
    ERROR_CONFLICTING_CLAIM
    ERROR_FORBIDDEN
    ERROR_ACCESS_DENIED
    ERROR_CONFLICT
    ERROR_VALIDATION
    ERROR_RATE_LIMIT
    ERROR_NOT_INSERTED
    ERROR_NOT_FOUND
    ERROR_TOO_MANY
    ERROR_TOO_MANY_ITEMS
    ERROR_TOO_MANY_SUBACCOUNTS
    ERROR_REQUEST_RATE_TOO_HIGH
    ERROR_DAILY_LIMIT_EXCEEDED
    ERROR_TOO_MANY_FAILED_AUTHS
    ERROR_INVALID_REQUEST
    ERROR_INVALID_TOKEN
    ERROR_INTERNAL_GOOGLE
    ERROR_MISSING_API_SCOPES
    ERROR_ADS_ACCOUNT_ALREADY_INVITED
    ERROR_ADS_ACCOUNT_ALREADY_MANAGED
    ERROR_WRONG_LOGIN_EMAIL
    $SUPPORTED_LOCALE_IDS
    $ALLOWED_AMOUNTS
    $ALLOWED_EXCEPTIONS_KG_VALUES
    $ALLOWED_EXCEPTION_ML_VALUES
    $GOOGLE_VALID_UNIT_TYPES
    $GOOGLE_VALID_UNIT_CODES
    $GOOGLE_VALID_AREA_UNIT
    $GOOGLE_VALID_LENGTH_UNIT
    $GOOGLE_VALID_VOLUME_UNIT
    $GOOGLE_VALID_WEIGHT_UNIT
    GOOGLE_DECIMAL_DIGITS
    GOOGLE_DECIMAL_FILL
    NUMBER_PRODUCTS_REQUEST_THRESHOLD
    ERROR_UNAUTHORIZED
);

use constant GOOGLE_SMART_SHOPPING_APP_SCOPES => qw (
    https://www.googleapis.com/auth/content
    https://www.googleapis.com/auth/siteverification
    https://www.googleapis.com/auth/adwords
    https://www.googleapis.com/auth/userinfo.email
);

use constant EPAGESJ_BASE_URI =>  'misc/google-smart-shopping/';

use constant MERCHANT_CENTER_REQUIREMENTS_CHECK_LIST => qw (
    ChecklistContactInfo
    ChecklistReturnPolicy
    ChecklistBillingTOC
    ChecklistGoogleAdsPolicies
    ChecklistCookieNotice
);

use constant ERROR_UNKNOWN                          => 'unknown_error';
use constant ERROR_FORM_SUBMIT                      => 'form_submit_failed';
use constant ERROR_ACCEPT_TERMS                     => 'not_accepted_terms';
use constant ERROR_TOKEN_EXPIRED_OR_REVOKED         => 'token_expired_or_revoked';
use constant ERROR_GET_VERIFICATION_TOKEN_FAILED    => 'timed_out';
use constant ERROR_UNAUTHENTICATED                  => 'not_authenticated';
use constant ERROR_CONFLICTING_CLAIM                => 'already_claimed';
use constant ERROR_FORBIDDEN                        => 'forbidden';
use constant ERROR_ACCESS_DENIED                    => 'access_denied';
use constant ERROR_CONFLICT                         => 'conflict';
use constant ERROR_VALIDATION                       => 'validation';
use constant ERROR_RATE_LIMIT                       => 'rate_limit';
use constant ERROR_REQUIRED_FIELD                   => 'required_field';
use constant ERROR_NOT_INSERTED                     => 'not_inserted';
use constant ERROR_NOT_FOUND                        => 'not_found';
use constant ERROR_TOO_MANY_ITEMS                   => 'too_many_items';
use constant ERROR_TOO_MANY_SUBACCOUNTS             => 'too_many_subaccounts';
use constant ERROR_REQUEST_RATE_TOO_HIGH            => 'request_rate_too_high';
use constant ERROR_DAILY_LIMIT_EXCEEDED             => 'daily_limit_exceeded';
use constant ERROR_TOO_MANY_FAILED_AUTHS            => 'too_many_failed_auths';
use constant ERROR_INVALID_REQUEST                  => 'invalid_request';
use constant ERROR_INVALID_TOKEN                    => 'invalid_token';
use constant ERROR_INTERNAL_GOOGLE                  => 'internal_google';
use constant ERROR_MISSING_API_SCOPES               => 'missing_api_scopes';
use constant ERROR_WRONG_LOGIN_EMAIL                => 'wrong_login_email';
use constant ERROR_ADS_ACCOUNT_ALREADY_INVITED      => 'ALREADY_INVITED_BY_THIS_MANAGER';
use constant ERROR_ADS_ACCOUNT_ALREADY_MANAGED      => 'ALREADY_MANAGED_BY_THIS_MANAGER';

use constant ERROR_UNAUTHORIZED => '401 Unauthorized';

use constant GOOGLE_ERROR_CODES => {
    'invalid'                       => ERROR_INVALID_REQUEST,
    'invalid_token'                 => ERROR_INVALID_TOKEN,
    'authError'                     => ERROR_UNAUTHENTICATED,
    'auth/account_access_denied'    => ERROR_ACCESS_DENIED,
    'conflict'                      => ERROR_CONFLICT,
    'internalError'                 => ERROR_INTERNAL_GOOGLE,
    'required'                      => ERROR_REQUIRED_FIELD,
    'userRateLimitExceeded'         => ERROR_RATE_LIMIT,
    'validation'                    => ERROR_VALIDATION,
    'not_inserted'                  => ERROR_NOT_INSERTED,
    'notFound'                      => ERROR_NOT_FOUND,
    'quota/too_many_items'          => ERROR_TOO_MANY_ITEMS,
    'quota/too_many_subaccounts'    => ERROR_TOO_MANY_SUBACCOUNTS,
    'quota/request_rate_too_high'   => ERROR_REQUEST_RATE_TOO_HIGH,
    'quota/daily_limit_exceeded'    => ERROR_DAILY_LIMIT_EXCEEDED,
    'quota/too_many_failed_auths'   => ERROR_TOO_MANY_FAILED_AUTHS,
};

use constant ACCOUNT_ISSUE_TRANSLATION_KEYS => {
    'pending_address_and_phone'                                                      => 'AccountLevelIssuePendingAddressAndPhone',
    'missing_ad_words_link'                                                          => 'AccountLevelIssueMissingAdsAccountLink',
    'invalid_store_name'                                                             => 'AccountLevelIssueInvalidStoreName',
    'editorial_and_professional_standards_destination_url_down_policy'               => 'AccountSuspendedDueToNonWorkingLandingPage',
    'home_page_issue'                                                                => 'AccountLevelIssueHomePageIssue',
    'misrepresentation_of_self_or_products_unacceptable_business_practice_policy'    => 'AccountLevelIssueUnacceptableBusinessPracticePolicy',
    'custom_label'                                                                   => 'AccountLevelIssueCustomLabel',
    'merchant_image_rejected'                                                        => 'AccountLevelIssueMerchantImageRejected',
    'misrepresentation_of_self_or_products_missing_refund_policy_policy'             => 'AccountLevelIssueMissingRefundPolicy',
    'misrepresentation_of_self_or_products_insufficient_contact_info_policy'         => 'AccountLevelIssueInsufficientContactInfoPolicy',

};

our $SUPPORTED_LOCALE_IDS = [qw (
    en_US
    de_DE
    en_GB
    fr_FR
    it_IT
    es_ES
    nl_NL
    en_AU
    pt_PT
    sv_SE
    fi_FI
    fr_BE
    nl_BE
    nl_NL
    es_MX
    en_CA
    fr_CA
    da_DK
)];


our $ALLOWED_AMOUNTS = [qw( 1 10 100 )];
our $ALLOWED_EXCEPTIONS_KG_VALUES = [qw( 50 1000 )];
our $ALLOWED_EXCEPTION_ML_VALUES = [qw( 750 )];
our $GOOGLE_VALID_UNIT_TYPES = [qw( length mass volume area )];
our $GOOGLE_VALID_AREA_UNIT = [qw( MTK )];
our $GOOGLE_VALID_LENGTH_UNIT = [qw( MTR CMT )];
our $GOOGLE_VALID_VOLUME_UNIT = [qw( LTR MTQ MLT )];
our $GOOGLE_VALID_WEIGHT_UNIT = [qw( GRM KGM MGM )];
our $GOOGLE_VALID_UNIT_CODES = [qw( GRM KGM MGM LTR MTQ MLT MTR CMT MTK )];

use constant GOOGLE_DECIMAL_DIGITS => 2;
use constant GOOGLE_DECIMAL_FILL => 1;
use constant NUMBER_PRODUCTS_REQUEST_THRESHOLD => 100;

1;
