package DE_EPAGES::GoogleSmartShopping::API::GooglePortalService;

use DE_EPAGES::Object::API::Factory qw ( LoadRootObject );
use DE_EPAGES::GoogleSmartShopping::API::Tools qw ( LogGoogleSmartShopping );

use strict;

sub new {
    my $class = shift;
    my ($hSettings)  = @_;

    my $self  = bless {
        Shop => $hSettings->{'Shop'},
    }, $class;

    return $self;
}

sub getSmartShoppingPortalConfig {
    my $self = shift;

    my $PortalConfigs = $self->{'Shop'}->get('PortalConfigs');
    return unless defined $PortalConfigs;

    foreach my $PortalConfig (@{$PortalConfigs}){
        if (index($PortalConfig->get('Alias') ,'GoogleSmartShopping') != -1) {

            return $PortalConfig;
        }
    }

    return;
}

sub getPortalConfigCreationParams {
    my $self = shift;


    my $GoogleSmartShoppingPortal = $self->_getGoogleSmartShoppingPortal();

    unless (defined $GoogleSmartShoppingPortal) {
        LogGoogleSmartShopping("getPortalConfigCreationParams failed - GoogleSmartShoppingPortal Not Found", {});
        return;
    }
    my $LocalizedPortalSite = $self->_getLocalizedPortalSite($GoogleSmartShoppingPortal);

    unless (defined $LocalizedPortalSite) {
        LogGoogleSmartShopping("getPortalConfigCreationParams failed - LocalizedPortalSite Not Found", {});
        return;
    }

    my $PortalConfigFolder = $self->{'Shop'}->folder('PortalConfigs');

    unless (defined $PortalConfigFolder) {
        LogGoogleSmartShopping("getPortalConfigCreationParams failed - PortalConfigFolder Not Found", {});
        return;
    }

    my $Class = $GoogleSmartShoppingPortal->get('PortalConfigClass');

    return {
        'Class'      => $Class,
        'Folder'     => $PortalConfigFolder,
        'PortalSite' => $LocalizedPortalSite
    }
}

sub _getGoogleSmartShoppingPortal {
    my $self = shift;

    my $System = LoadRootObject();
    my $aPortals = $System->get('Portals');

    foreach my $Portal (@{$aPortals}) {
        if ($Portal->get('NameOrAlias') eq 'GoogleSmartShopping') {

            return $Portal;
        }
    }

    return;
}

sub _getLocalizedPortalSite {
    my $self = shift;
    my ($GoogleSmartShoppingPortal) = @_;

    my $ShopLocaleID = $self->{'Shop'}->get('LocaleID');
    foreach my $LocalizedPortalSite (@{$GoogleSmartShoppingPortal->get('PortalSites')}) {
        if ($LocalizedPortalSite->get('LocaleID') eq $ShopLocaleID) {

            return $LocalizedPortalSite;
        }
    }

    return;
}

sub deleteSmartShoppingPortalConfig {
    my $self = shift;
    my $SmartShoppingPortalConfig = $self->getSmartShoppingPortalConfig();
    return unless defined $SmartShoppingPortalConfig;

    $SmartShoppingPortalConfig->delete();
}
1;
