#========================================================================================
# package      DE_EPAGES::GoogleSmartShopping::t::unit::PagerMerchantCenterProducts
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for the GoogleSmartShopping ProductFeed tab
#========================================================================================
package DE_EPAGES::GoogleSmartShopping::t::unit::PagerMerchantCenterProducts;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::MockifyServlet;

use Test::Mockify;
use Test::Mockify::Matcher qw ( String HashRef );
use Test::Mockify::Sut;
use Test::Mockify::Verify qw ( WasCalled );

use Test::More;

use strict;

sub test {
    my $self = shift;

    $self->test_Pager_Execute_Success_NoProducts();

    done_testing();
}


sub test_Pager_Execute_Success_NoProducts {
    my $self = shift;
    my $SubTestName = ( caller(0) )[3];

    my $MockedShop = $self->_createShop();
    my $MockedPortalConfig = $self->_createPortalConfig({ MockedShop => $MockedShop});
    my $GoogleApiService = $self->_createGoogleApiService({ 'ProductsStatuses' => {} });

    # when Servlet base class calls ExistsClassByAlias, call without Servlet
    my $hParams = {
        'Object'           => $MockedPortalConfig,
        'ObjectID'         => '12345',
        'GoogleApiService' => $GoogleApiService,
    };

    my $SUT = $self->_createSUT($hParams);

    is_deeply($SUT->items(),[], "$SubTestName - Verify pager items.");
    is($SUT->countItems(),0, "$SubTestName - Verify pager count items.");

    $SUT->execute($GoogleApiService);

    ok(WasCalled($GoogleApiService, 'productsStatuses'),
        $SubTestName . ' - Verify that service method productsStatuses was called.');

}

#----------------------------------------------------------------------------------------
# Mockery
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;
    my ($hParams ) = @_;

    my $MockifySut = Test::Mockify::Sut->new('DE_EPAGES::GoogleSmartShopping::API::Object::PagerMerchantCenterProducts',[$hParams]);

    $MockifySut->mockImported('DE_EPAGES::GoogleSmartShopping::API::Tools', 'LogGoogleSmartShopping')
        ->whenAny()
        ->thenReturnUndef();

    if (defined $hParams->{'GoogleApiService'}) {
        $MockifySut->mockStatic('DE_EPAGES::GoogleSmartShopping::API::GoogleApiService::new')
            ->when(String(), HashRef())
            ->thenReturn($hParams->{'GoogleApiService'});
    }

    return $MockifySut->getMockObject();
}

sub _createPortalConfig {
    my $self = shift;
    my ($hParams) = @_;

    my $hAttributes = {};

    my $MockifyPortalConfig = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::GoogleSmartShopping::API::Object::GoogleSmartShoppingPortalConfig', $hAttributes
    );

    $MockifyPortalConfig->addMockWithReturnValue('getSite', $hParams->{'MockedShop'});

    return $MockifyPortalConfig->getMockObject();
}

sub _createShop {
    my $self = shift;

    my $MockifyShop = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {});

    return $MockifyShop->getMockObject();
}

sub _createGoogleApiService {
    my $self = shift;
    my ($hServiceResponse) = @_;

    my $Mockify = Test::Mockify->new('DE_EPAGES::GoogleSmartShopping::API::GoogleApiService');

    $Mockify->mock('productsStatuses')->when()->thenReturn($hServiceResponse->{'ProductsStatuses'} // {});

    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();
