#========================================================================================
# package      DE_EPAGES::Order::DAL::Order
# state        private
# description  database interface for tables:
#               <ul>
#                   <li>customerorder
#               </ul>
#========================================================================================
package DE_EPAGES::Order::DAL::Order;
use base qw (Exporter);

use strict;
our @EXPORT = qw (
    DAL_UnseenOrderCount
    DAL_TotalOrdersCount
);

use DE_EPAGES::Core::API::Log qw ( GetLog );
use DE_EPAGES::Database::API::Connection qw (  GetCurrentDBHandle );
use DE_EPAGES::Database::API::DAL;

my $DAL_PACKAGE = 'DE_EPAGES::Database::API::DAL';
my $DO_CACHE = 1;

sub _CallDriver {
    my ($FunctionName, @Parameter) = @_;
    my $dbi = GetCurrentDBHandle();
    my $Package = 'DE_EPAGES::Order::DAL::'.$dbi->driverName.'::Order';
    DE_EPAGES::Core::API::PerlTools::UsePackage($Package);
    GetLog->debug("call $Package->$FunctionName()");
    return $Package->$FunctionName($dbi, @Parameter);
}

#========================================================================================
# function     DAL_UnseenOrderCount
#----------------------------------------------------------------------------------------
# syntax       $OrderCount = DAL_UnseenOrderCount(ShopID);
#----------------------------------------------------------------------------------------
# description  Returns count of unseen order for shop.
#----------------------------------------------------------------------------------------
# input        $ShopID | shop id | integer
# return       $OrderCount | count of unseen orders  | int
#========================================================================================
sub DAL_UnseenOrderCount ($) {
    my ($ShopID) = @_;
    return _CallDriver('GetUnseenOrderCount', $ShopID);
}

#========================================================================================
# function     DAL_TotalOrdersCount
#----------------------------------------------------------------------------------------
# syntax       $TotalOrdersCount = DAL_TotalOrdersCount(ShopID);
#----------------------------------------------------------------------------------------
# description  Returns the total number of orders for a shop
#----------------------------------------------------------------------------------------
# input        $ShopID | shop id | integer
# return       $TotalOrdersCount | total count of orders  | int
#========================================================================================
sub DAL_TotalOrdersCount ($) {
    my ($ShopID) = @_;
    return _CallDriver('GetTotalOrdersCount', $ShopID);
}

1;
