#========================================================================================
# package      DE_EPAGES::Order::DAL::SQL::Order
# state        private
# description  Generic SQL database interface for tables:
#               <ul>
#                   <li>customerorder
#               </ul>
#========================================================================================
package DE_EPAGES::Order::DAL::SQL::Order;

use strict;
use DE_EPAGES::Core::API::Error qw (Error);

my %TABLE_DEF = (
);

sub ErrorDefinition { return {
    'TableNotExists'  => 'table #Table does not exist at package DE_EPAGES::Order::DAL::SQL::Order',
    'ColumnNotExists' => 'column #Column does not exist at table #Table at package DE_EPAGES::Order::DAL::SQL::Order',
}}

sub TableDef {
    my $self = shift;
    my ($Table, $Column) = @_;
    Error('TableNotExists',  {'Table'=>$Table, 'Column'=>$Column }) unless exists $TABLE_DEF{$Table};
    Error('ColumnNotExists', {'Table'=>$Table, 'Column'=>$Column }) unless exists $TABLE_DEF{$Table}{$Column};
    return $TABLE_DEF{$Table}{$Column}[0];
}

sub TableType {
    my $self = shift;
    my ($Table, $Column) = @_;
    Error('TableNotExists',  {'Table'=>$Table, 'Column'=>$Column }) unless exists $TABLE_DEF{$Table};
    Error('ColumnNotExists', {'Table'=>$Table, 'Column'=>$Column }) unless exists $TABLE_DEF{$Table}{$Column};
    return $TABLE_DEF{$Table}{$Column}[1];
}

#========================================================================================
# function     GetUnseenOrderCount
#----------------------------------------------------------------------------------------
# syntax       $OrderCount = $Package->GetUnseenOrderCount($dbi, $ShopID);
#----------------------------------------------------------------------------------------
# description  Returns count of unseen order for shop.
#----------------------------------------------------------------------------------------
# input        $dbh | database handle | object
# input        $ShopID | shop id | integer
# return       $OrderCount | count of unseen orders  | int
#========================================================================================
sub GetUnseenOrderCount {
    my $self = shift;
    my $dbi = shift;
    my $ShopID = shift;

    my $sql = <<END_SQL;
SELECT count(*)
FROM customerorder co
WHERE co.shopid = ?
AND viewedon is null
END_SQL
    my $dbResult = $dbi->execute( $sql, [$ShopID], ['Integer']);

    return $dbResult->[0]->[0];
}

#========================================================================================
# function     GetTotalOrdersCount
#----------------------------------------------------------------------------------------
# syntax       $TotalOrdersCount = $Package->GetTotalOrdersCount($dbi, $ShopID);
#----------------------------------------------------------------------------------------
# description  Returns the total number of orders for a shop
#----------------------------------------------------------------------------------------
# input        $dbh | database handle | object
# input        $ShopID | shop id | integer
# return       $TotalOrdersCount | Total number of orders for this shop | int
#========================================================================================
sub GetTotalOrdersCount {
    my $self = shift;
    my $dbi = shift;
    my $ShopID = shift;

    my $sql = <<END_SQL;
select count(orderid) from customerorder where shopid=?
END_SQL
    my $dbResult = $dbi->execute( $sql, [$ShopID], ['Integer']);

    return $dbResult->[0]->[0];
}

1;
