#========================================================================================
# package      DE_EPAGES::PayPalPPCP::API::Constants
# state        public
# description  constants for cartridge
#========================================================================================
package DE_EPAGES::PayPalPPCP::API::Constants;
use base Exporter;

use strict;
use Readonly;

our @EXPORT_OK = qw (
    $USE_CURL
    $MERCHANT_INFO_REFRESH_THRESHOLD_MINS
    $TOKEN_EXPIRE_THRESHOLD_MINS
    $INVOICE_FS
    $TOKEN_ENDPOINT
    $PARTNER_REFERRAL_ENDPOINT
    $GET_MERCHANT_INFO_ENDPOINT
    $GET_MERCHANT_APP_ENDPOINT
    $WEBHOOKS_ENDPOINT
    $WEBHOOK_VERIFY_ENDPOINT
    $TRANSACTIONS_ENDPOINT
    $ORDERS_ENDPOINT
    $INVOICES_ENDPOINT

    $ORDER_STATUS_CREATED
    $ORDER_STATUS_VOIDED
    $ORDER_STATUS_APPROVED
    $ORDER_STATUS_COMPLETED
    $ORDER_STATUS_PENDING_APPROVAL
    $ORDER_STATUS_PARTIALLY_REFUNDED
    $ORDER_STATUS_REFUNDED

    $PPCP_ADDRESS_ALIAS

    WEBHOOK_EVENT_TYPES
);

our %EXPORT_TAGS = ( ALL => [ @EXPORT_OK ] );

Readonly::Scalar our $USE_CURL => 1;

#-- How often we can refresh the Merchant Info from PayPal
Readonly::Scalar our $MERCHANT_INFO_REFRESH_THRESHOLD_MINS => 1;

Readonly::Scalar our $TOKEN_EXPIRE_THRESHOLD_MINS => 30;

Readonly::Scalar our $INVOICE_FS => 'invoice';

Readonly::Scalar our $TOKEN_ENDPOINT => 'v1/oauth2/token';

Readonly::Scalar our $PARTNER_REFERRAL_ENDPOINT => 'v2/customer/partner-referrals';

Readonly::Scalar our $GET_MERCHANT_INFO_ENDPOINT => 'v1/customer/partners/{partner_merchant_id}/merchant-integrations/';

Readonly::Scalar our $GET_MERCHANT_APP_ENDPOINT => 'v1/customer/partners/{partner_merchant_id}/merchant-integrations/credentials/';

Readonly::Scalar our $WEBHOOKS_ENDPOINT => 'v1/notifications/webhooks';

Readonly::Scalar our $WEBHOOK_VERIFY_ENDPOINT => 'v1/notifications/verify-webhook-signature';

Readonly::Scalar our $TRANSACTIONS_ENDPOINT => 'v1/reporting/transactions';

Readonly::Scalar our $ORDERS_ENDPOINT => 'v2/checkout/orders';

Readonly::Scalar our $INVOICES_ENDPOINT => 'v2/invoicing/invoices';

Readonly::Scalar our $ORDER_STATUS_CREATED => 'CREATED';
Readonly::Scalar our $ORDER_STATUS_VOIDED => 'VOIDED';
Readonly::Scalar our $ORDER_STATUS_APPROVED => 'APPROVED';
Readonly::Scalar our $ORDER_STATUS_COMPLETED => 'COMPLETED';
Readonly::Scalar our $ORDER_STATUS_PENDING_APPROVAL => 'PENDING_APPROVAL';
Readonly::Scalar our $ORDER_STATUS_PARTIALLY_REFUNDED => 'PARTIALLY_REFUNDED';
Readonly::Scalar our $ORDER_STATUS_REFUNDED => 'REFUNDED';

Readonly::Scalar our $PPCP_ADDRESS_ALIAS => 'PPCPAddress';

#========================================================================================
# global       WEBHOOK_EVENT_TYPES | list of webhook events we listen on: | json list
# description  see: https://developer.paypal.com/docs/api-basics/notifications/webhooks/event-names/
#========================================================================================
use constant WEBHOOK_EVENT_TYPES => <<"END";
  "event_types": [
    {
      "name": "PAYMENT.CAPTURE.REFUNDED"
    },
    {
      "name": "PAYMENT.CAPTURE.COMPLETED"
    },
    {
      "name": "PAYMENT.CAPTURE.DENIED"
    },
    {
      "name": "CHECKOUT.PAYMENT-APPROVAL.REVERSED"
    }
  ]
END

1;
