#========================================================================================
# package      DE_EPAGES::PayPalPPCP::API::Order
# state        public
#----------------------------------------------------------------------------------------
# description  Helper subroutines
#========================================================================================
package DE_EPAGES::PayPalPPCP::API::Order;
use base qw( Exporter );

use strict;
use DE_EPAGES::PayPalPPCP::API::Constants qw ( $PPCP_ADDRESS_ALIAS );

our @EXPORT_OK = qw(
    CleanUpPayPalAddress
);

#========================================================================================
# function     CleanUpPayPalAddress
#----------------------------------------------------------------------------------------
# syntax       CleanUpPayPalAddress($Order);
#----------------------------------------------------------------------------------------
# description  Remove any addresses we copied from PayPal from the order user object
#----------------------------------------------------------------------------------------
# input        $Order | order | object
#========================================================================================
sub CleanUpPayPalAddress {
    my ($Order) = @_;

    my $User = $Order->get('User');
    return if ! $User;
    return if $User->get('IsAnonymous');

    my $UserAddresses = $User->folder('Addresses');

    my $PPCPAddressAlias = $PPCP_ADDRESS_ALIAS;
    $UserAddresses->child($PPCPAddressAlias)->delete if $UserAddresses->existsChild($PPCPAddressAlias);

    #-- Reset the user shipping address back to its original shipping address, if there is one
    if ( !$User->get('ShippingAddress') && $User->get('BillingAddress') ) {
        foreach my $Address ( @{$UserAddresses->childrenByClass('Address')} ) {
            if ( $Address->id != $User->get('BillingAddress')->id ) {
                $User->set({
                    'ShippingAddress' => $Address,
                });
            }
        }
    }
}

1;
