#========================================================================================
# §package      DE_EPAGES::PayPalPPCP::Hooks::Order
# §state        public
# §description  Additional hook functions for Order class
#========================================================================================
package DE_EPAGES::PayPalPPCP::Hooks::Order;

use strict;
use DE_EPAGES::PayPalPPCP::API::Constants qw ( $ORDER_STATUS_PENDING_APPROVAL );
use DE_EPAGES::PayPalPPCP::API::Order qw ( CleanUpPayPalAddress ); ##no critic qw(DE_EPAGES::Style::RequireCorrectImports)

#========================================================================================
# §function     OnUI_Basket2OrderMultiStepCheckout
# §state        public
#----------------------------------------------------------------------------------------
# §syntax       OnUI_Basket2OrderMultiStepCheckout( $hParams );
#----------------------------------------------------------------------------------------
# §description  Triggered by hook UI_Basket2OrderMultiStepCheckout.
#               - Create an order with payment source 'payment_on_invoice', stop basket2order on error
#----------------------------------------------------------------------------------------
# §input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Basket - basket object</li>
#                   <li>Servlet - servlet</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnUI_Basket2OrderMultiStepCheckout {
    my ($hParams) = @_;

    my $Basket = $hParams->{'Basket'};
    my $Servlet = $hParams->{'Servlet'};

    my $PaymentLine = $Basket->container->get('Payment');
    return if !$PaymentLine || !$PaymentLine->instanceOf('LineItemPaymentPayPalPPCP') || !$PaymentLine->get('PayViaPUI');

    my $PaymentMethod = $PaymentLine->get('PaymentMethod');

    my $BillingAddress = $Basket->get('BillingAddress');
    my $Birthday = $BillingAddress->get('Birthday');
    my $Phone = $BillingAddress->get('Phone');
    if ( !$Birthday || !$Phone ) {
        $Servlet->form->executeFormError({
            'ViewAction' => 'ViewMultiCheckoutPayment',
            'Name' => 'MAND_FIELDS',
            'Reason' => 'PUI_INVALID_MAND_FIELDS',
            'Form' => 'SavePUI',
        });
    }

    #-- Create the PUI Order
    my ($hJsonResponse, $hPayLoad) = $PaymentMethod->createPUIOrder($PaymentLine);

    my $IsSuccess = defined $hJsonResponse && $hJsonResponse->{'status'} eq $ORDER_STATUS_PENDING_APPROVAL;

    if ( ! $IsSuccess ) {
        my $Reason = 'PPCP_PUI_FAILED';

        if ( defined $hJsonResponse && $hJsonResponse->{'name'} eq 'UNPROCESSABLE_ENTITY') {
            foreach ( @{$hJsonResponse->{'details'}} ) {
                $Reason = $_->{'issue'};
            }
        }

        $Servlet->vars('PUI_CREATE_ORDER_ERROR', 1);
        $Servlet->form->executeFormError({
            'Reason' => $Reason,
            'Name' => 'PPCP_PUI',
            'ViewAction' => 'ViewMultiCheckoutConfirmation',
        });
    }

    $PaymentLine->set({
        'OrderInfoJSON' => $hJsonResponse,
        'OrderPayload'  => $hPayLoad,
        'TransID2'      => $hJsonResponse->{'id'},
    });
}

#========================================================================================
# §function     OnAPI_OrderCreated
# §state        public
#----------------------------------------------------------------------------------------
# §syntax       OnAPI_OrderCreated( $hParams );
#----------------------------------------------------------------------------------------
# §description  Triggered by hook API_OrderCreated.
#----------------------------------------------------------------------------------------
# §input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Order - order object</li>
#                   <li>Options - options hash</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnAPI_OrderCreated {
    my ($hParams) = @_;

    my $Order = $hParams->{'Order'};

    CleanUpPayPalAddress($Order);
}

1;
