#========================================================================================
# §package      DE_EPAGES::PayPalPPCP::Hooks::Shop
# §state        public
# §description  Additional hook function for OnLoadCheckoutCSS hook.
#========================================================================================
package DE_EPAGES::PayPalPPCP::Hooks::Shop;

use strict;
use DE_EPAGES::WebInterface::API::ApplicationServer qw (GetAppServer);

#========================================================================================
# §function     OnLoadCheckoutCSS
# §state        public
#----------------------------------------------------------------------------------------
# §syntax       OnLoadCheckoutCSS($hParams);
#----------------------------------------------------------------------------------------
# §description  Triggered by hook OBJ_LoadCheckoutCSS.
#               Checks if the CSS for the checkout should be requested from Unity via REST
#               or the related shop attribute is taken
#----------------------------------------------------------------------------------------
# §input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Object - shop object</li>
#                   <li>Values - attributes</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnLoadCheckoutCSS {
    my ($hParams) = @_;

    # skip if another hook function already wants to request the CSS from Unity
    return if $hParams->{'Values'}->{'RequestCSSPathFromUnity'};

    if( defined $hParams->{'Values'}->{'ViewAction'}
        && $hParams->{'Values'}->{'ViewAction'} eq 'ViewMultiCheckoutConfirmation') {

        my $Fppcp;
        eval {
            my $AppServer = GetAppServer();
            my $Servlet = $AppServer->currentServlet();
            $Fppcp = $Servlet->form->value('Fppcp');
        };
        $Fppcp = undef if $@;

        #-- Only request the css if coming from the ppcp express button on the cart page as it will go straight to the 'check and confirm' page
        #-- If checking out normally, the css is refreshed through other means so we don't need to do this
        if ( $Fppcp ) {
            $hParams->{'Values'}->{'RequestCSSPathFromUnity'} = 1;
        }
    }

    return;
}

1;
