#===============================================
#   Since internal machines cannot receive webhooks
#       Run this script to retrieve an update to a PUI order from PayPal
#       And to trigger off either an Approved/Declined email for said order
#
#
#================================================
use strict;
use Getopt::Long;
use Time::HiRes qw (time);

use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Connection qw( RunOnStore );
use DE_EPAGES::Order::API::Cartridge;
use DE_EPAGES::Object::API::Factory qw ( LoadObject );
use DE_EPAGES::WebInterface::API::MessageCenter qw ( SynchronizeCache );

use DE_EPAGES::PayPalPPCP::UI::PaymentMethodPayPalPPCPWebHooks;

sub Main {

    local $| = 1;

    my $Password;
    my $StoreName;
    my $Help;
    my $NoOutput;
    my $OrderID;
    my $MailAlias;

    GetOptions(
        'help'        => \$Help,
        'nooutput'    => \$NoOutput,
        'passwd=s'    => \$Password,
        'storename=s' => \$StoreName,
        'orderid=s'   => \$OrderID,
        'mailtype=s'  => \$MailAlias,
    );

    usage() if $Help;

    unless ( defined $StoreName ) {
        print STDERR "Missing parameter -storename.\n\n";
        usage();
    }
    unless ( defined $OrderID ) {
        print STDERR "Missing parameter -orderid.\n\n";
        usage();
    }
    unless ( defined $MailAlias ) {
        print STDERR "Missing parameter -mailtype.\n\n";
        usage();
    }
    my $time1 = time;

    RunOnStore(
        Store      => $StoreName,
        DBPassword => $Password,
        Sub        => sub { 
            my $Order = LoadObject($OrderID);
            my $Container = $Order->container;
            my $PaymentLine = $Container->get('Payment');
            die 'Not a PPCP line item' unless $PaymentLine->instanceOf('LineItemPaymentPayPalPPCP');
            die 'Not a PUI line item' unless $PaymentLine->get('PayViaPUI');

            if ( $PaymentLine->get('OrderInfoJSON') && $PaymentLine->get('OrderInfoJSON')->{'status'} eq 'PENDING_APPROVAL' ) {
                my $PaymentMethodPayPalPPCP = $PaymentLine->get('PaymentMethod');
                if ( $PaymentMethodPayPalPPCP ) {
                    my $hJsonResponse = $PaymentMethodPayPalPPCP->getPPCPOrder($PaymentLine);
                    if ( $hJsonResponse ) {
                        $PaymentLine->set({
                            'OrderInfoJSON' => $hJsonResponse,
                        });
                        $PaymentLine->updateLineItemFromPPCP();
                        SynchronizeCache();
                    }
                }
            }

            DE_EPAGES::PayPalPPCP::UI::PaymentMethodPayPalPPCPWebHooks::_sendInvoiceEmail($PaymentLine, $MailAlias); ##no critic qw(Subroutines::ProtectPrivateSubs)
        },
    );
    my $time2 = time;
    printf "need %.1f seconds\n", $time2 - $time1 unless $NoOutput;
}

sub usage {
    print <<END_USAGE;
Description:
    Calculates sales volume for every shop

Usage:
    perl $0 [options] [flags] datafiles

options:
    -passwd     database user password                          ()
    -storename  name of store                                   ()
    -mailtype   mail type to send                               (PayPalPPCPInvoiceApproved|PayPalPPCPInvoiceDeclined)
    -nooutput   do not print any output

flags:
    -help       show the command line options

Example:
    perl $0 -storename Store -orderid 13833 -mailtype PayPalPPCPInvoiceDeclined
END_USAGE
    exit 2;
}

RunScript( 'Sub' => \&Main );
