#========================================================================================
# §package      DE_EPAGES::PayPalPPCP::UI::PaymentMethodPayPalPPCPWebHooks
# §base         use base DE_EPAGES::Presentation::UI::JSON;
# §state        public
#----------------------------------------------------------------------------------------
# §description  UI subs for the PayPalPPCP Webhook Callback
#========================================================================================
package DE_EPAGES::PayPalPPCP::UI::PaymentMethodPayPalPPCPWebHooks;
use base DE_EPAGES::Presentation::UI::JSON;

use strict;
use JSON;
use HTTP::Status qw ( HTTP_OK HTTP_BAD_REQUEST );

use DE_EPAGES::Object::API::Factory qw ( LoadClassByAlias );
use DE_EPAGES::Core::API::PerlTools qw( GetCurrentDateTime AddDuration );
use DE_EPAGES::ShopMailType::API::ShopMailType qw ( GetShopMailType );
use DE_EPAGES::Core::API::Warning qw ( Warning );
use DE_EPAGES::Object::API::Language qw ( GetCodeByLanguageID );


use DE_EPAGES::PayPalPPCP::API::Constants qw ( $ORDER_STATUS_PARTIALLY_REFUNDED $ORDER_STATUS_REFUNDED );
#use DE_EPAGES::PayPalPPCP::API::Order qw ( SetTransStatus );

#========================================================================================
# §function     PayPalWebhookCallback
# §state        public
#----------------------------------------------------------------------------------------
# §syntax       $self->PayPalWebhookCallback( $Servlet );
#----------------------------------------------------------------------------------------
# §description  Webhook callback function for PPCP
#----------------------------------------------------------------------------------------
# §input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::Permission
#========================================================================================
sub PayPalWebhookCallback {
    my $self = shift;
    my ($Servlet) = @_;

    my $PaymentMethodPayPalPPCP = $Servlet->object();

    return _DoResponse($Servlet, 0) if ! $PaymentMethodPayPalPPCP->hasAppCredentials();

    my $IncomingRequest = $Servlet->request;
    my $Headers = $Servlet->requestHeaders();
    my $EventContent = $IncomingRequest->content;

    $PaymentMethodPayPalPPCP->logPPCP('PPCP WebHookCallback', $EventContent);

    # verify Webhook by sending data back to PayPal. see: https://developer.paypal.com/api/webhooks/v1/
    my $IsVerified = $PaymentMethodPayPalPPCP->verifyWebHookCallBack({'Headers' => $Headers, 'EventContent' => $EventContent});

    return _DoResponse($Servlet, 1) unless $IsVerified;

    #$PaymentMethodPayPalPPCP->logPPCP('IsVerified', $IsVerified);

    my $hWebhookEvent = undef;
    eval { $hWebhookEvent = decode_json($EventContent); };
    return _DoResponse($Servlet, 1) if $@;

    # proceed with reading the content from the WebHook call
    my $EventType = $hWebhookEvent->{'event_type'};

    #do we have a valid EventType from Constants.pm ?
    # react aso with HTTP_OK if not (call is valid but we don't need this data)
    #return _DoResponse($Servlet, 0) unless WEBHOOK_EVENT_TYPES =~ /$EventType/g;

    my $Class = LoadClassByAlias('LineItemPaymentPayPalPPCP');

    #$PaymentMethodPayPalPPCP->logPPCP('event type', $EventType);

    #--
    #-- !!!!!!!!!!!! UNTESTED !!!!!!!!!!!!!!!!!
    #--
    #-- This hook is only needed for PUI orders, and the assumed data structure comes from
    #-- https://developer.paypal.com/limited-release/orders-apms/pay-upon-invoice/integrate-pui-merchants/#link-steplistentowebhookstogettheresultofordercapture
    if ( $EventType eq 'PAYMENT.CAPTURE.DENIED' ) {
        my $OrderID = $hWebhookEvent->{'resource'}->{'supplementary_data'}->{'related_ids'}->{'order_id'};
        return _DoResponse($Servlet, 0) unless $OrderID;

        my $aPPLineItemList  = $Class->getObjects('ByTransID2',[$OrderID]);
        return _DoResponse($Servlet, 0) unless scalar @$aPPLineItemList;

        my $LineItem = $aPPLineItemList->[0];
        return _DoResponse($Servlet, 0) if ! $LineItem->get('PayViaPUI');

        my $hJsonResponse = $PaymentMethodPayPalPPCP->getPPCPOrder($LineItem);
        if ( $hJsonResponse ) {
            $LineItem->set({
                'OrderInfoJSON' => $hJsonResponse,
            });

            my $Order = $LineItem->get('LineItemContainer')->parent();

            $Order->set({
                'CancelledOn' => GetCurrentDateTime(),
                'PaidOn' => undef,
            });

            #-- Send the declined email
            eval {
                _sendInvoiceEmail($LineItem, 'PayPalPPCPInvoiceDeclined');
            };

            #-- This email MUST be sent for us to consider it a success
            return _DoResponse($Servlet, 1) if $@;
        } else {
            return _DoResponse($Servlet, 1);
        }
    }

    #--
    #-- !!!!!!!!!!!! UNTESTED !!!!!!!!!!!!!!!!!
    #--
    #-- This hook is only needed for PUI orders, and the assumed data structure comes from
    #-- https://developer.paypal.com/limited-release/orders-apms/pay-upon-invoice/integrate-pui-merchants/#link-steplistentowebhookstogettheresultofordercapture
    if ( $EventType eq 'CHECKOUT.PAYMENT-APPROVAL.REVERSED' ) {
        my $OrderID = $hWebhookEvent->{'resource'}->{'order_id'};
        return _DoResponse($Servlet, 0) unless $OrderID;

        my $aPPLineItemList  = $Class->getObjects('ByTransID2',[$OrderID]);
        return _DoResponse($Servlet, 0) unless scalar @$aPPLineItemList;

        my $LineItem = $aPPLineItemList->[0];
        return _DoResponse($Servlet, 0) if ! $LineItem->get('PayViaPUI');

        my $hJsonResponse = $PaymentMethodPayPalPPCP->getPPCPOrder($LineItem);
        if ( $hJsonResponse ) {
            $LineItem->set({
                'OrderInfoJSON' => $hJsonResponse,
            });

            my $Order = $LineItem->get('LineItemContainer')->parent();

            $Order->set({
                'CancelledOn' => GetCurrentDateTime(),
                'PaidOn' => undef,
            });

            #-- Send the declined email
            eval {
                _sendInvoiceEmail($LineItem, 'PayPalPPCPInvoiceDeclined');
            };

            #-- This email MUST be sent for us to consider it a success
            return _DoResponse($Servlet, 1) if $@;
        } else {
            return _DoResponse($Servlet, 1);
        }
    }

    if ( $EventType eq 'PAYMENT.CAPTURE.REFUNDED' ) {
        #$PaymentMethodPayPalPPCP->logPPCP('event type', $EventType);
        my $CustomID = $hWebhookEvent->{'resource'}->{'custom_id'};
        my $LineItem;
        eval {
            $LineItem = $PaymentMethodPayPalPPCP->getSite()->loadObject( $CustomID, 'LineItemPaymentPayPalPPCP' );
        };
        return _DoResponse($Servlet, 0) if $@ || ! $LineItem;

        my $hJsonResponse = $PaymentMethodPayPalPPCP->getPPCPOrder($LineItem);
        if ( $hJsonResponse ) {
            $LineItem->set({
                'OrderInfoJSON' => $hJsonResponse,
            });

            my $Order = $LineItem->get('LineItemContainer')->parent();

            my $hPurchaseUnit = $hJsonResponse->{'purchase_units'}->[0];
            my $hCapture = $hPurchaseUnit->{'payments'}->{'captures'}->[0];
            if ( $hCapture->{'status'} eq $ORDER_STATUS_PARTIALLY_REFUNDED ) {
                $Order->set({
                    'PartlyPaidOn' => GetCurrentDateTime(),
                    'PaidOn' => undef,
                });
            } elsif ( $hCapture->{'status'} eq $ORDER_STATUS_REFUNDED ) {
                $Order->set({
                    'PartlyPaidOn' => undef,
                    'PaidOn' => undef,
                    'CancelledOn' => GetCurrentDateTime(),
                });
            }

        } else {
            return _DoResponse($Servlet, 1);
        }
    }

    if ( $EventType eq 'PAYMENT.CAPTURE.COMPLETED' ) {
        #$PaymentMethodPayPalPPCP->logPPCP('event type', $EventType);
        #my $PaymentID = $hWebhookEvent->{'resource'}->{'id'};
        my $OrderID = $hWebhookEvent->{'resource'}->{'supplementary_data'}->{'related_ids'}->{'order_id'};
        return _DoResponse($Servlet, 0) unless $OrderID;

        my $aPPLineItemList  = $Class->getObjects('ByTransID2',[$OrderID]);
        return _DoResponse($Servlet, 0) unless scalar @$aPPLineItemList;

        my $LineItem = $aPPLineItemList->[0];
        #-- We don't need this webhook unless the order is a PUI one
        return _DoResponse($Servlet, 0) if ! $LineItem->get('PayViaPUI');

        #-- Give time for the basket2order to complete? I'm not sure if this typically triggered immediately after the order api call
        #-- In SandBox, it happens immediately, but it may not in live
        #-- The hook seems to trigger after at least 10 seconds, so we should be good . . .

        my $hJsonResponse = $PaymentMethodPayPalPPCP->getPPCPOrder($LineItem);
        if ( $hJsonResponse ) {
            $LineItem->set({
                'OrderInfoJSON' => $hJsonResponse,
            });

            my $Order = $LineItem->get('LineItemContainer')->parent();

            $LineItem->updateLineItemFromPPCP();
            $Order->set({
                'PaidOn' => GetCurrentDateTime(),
            });

            #-- Send a separate email with the bank details to deposit into
            eval {
                _sendInvoiceEmail($LineItem, 'PayPalPPCPInvoiceApproved');
            };

            #-- This email MUST be sent for us to consider it a success
            return _DoResponse($Servlet, 1) if $@;
        } else {
            return _DoResponse($Servlet, 1);
        }
    }

    return _DoResponse($Servlet, 0);
}

sub _DoResponse {
    my ($Servlet, $IsError) = @_;

    $Servlet->response->code($IsError ? HTTP_BAD_REQUEST : HTTP_OK);
    return $Servlet->writeContentOutput();
}

#===========================================
# Send the given email event with alias '$MailTypeAlias'
#===================================================
sub _sendInvoiceEmail {
    my ($PaymentLine, $MailTypeAlias) = @_;

    my $Order = $PaymentLine->get('LineItemContainer')->parent();
    my $Shop = $Order->getSite();
    my $MailType = GetShopMailType( $Shop, $MailTypeAlias );

    #-- don't event try to send an e-mail if the merchant doesn't have a sender e-mail
    my $From = $MailType->from;

    unless( defined $From && $From =~ /\S/ ) {
        Warning('MISSING_FROM', {'ShopAlias' => $Shop->alias});
        return;
    }

    my $BillingAddress = $Order->get('BillingAddress') ? $Order->get('BillingAddress'): $Order->get('Customer')->get('BillingAddress');
    my $Email = $BillingAddress->get('EMail');

    #-- create and send mail
    my %MailParams = (
        'HTMLAllowed' => defined $Order->get('User') ? $Order->get('User')->get('IsHtmlEMailAllowed') : 1,
        'Attachments' => [],
    );
    $MailParams{'TO'} = $Email if defined $Email;

    my %Vars = (
        IsUnityEmailConfirmation => $Shop->get('IsUnityRegistered'),
        DueDate => AddDuration($Order->get('CreationDate'), 'days', 30), #-- The calculated due date, 30 days after order creation
    );
    my $Container = $Order->get('LineItemContainer');
    my %RegionalParams = (
        Locale      => $Container->get('LocaleID'),
        Language    => GetCodeByLanguageID($Container->get('LanguageID')),
    );

    $MailType->send( $Order, \%MailParams, \%RegionalParams, \%Vars );
}

1;
